==> kubernetes-model-apps-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/apps/StatefulSetPersistentVolumeClaimRetentionPolicyFluent.java <==
package io.fabric8.kubernetes.api.model.apps;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class StatefulSetPersistentVolumeClaimRetentionPolicyFluent<A extends StatefulSetPersistentVolumeClaimRetentionPolicyFluent<A>> extends BaseFluent<A>{
  public StatefulSetPersistentVolumeClaimRetentionPolicyFluent() {
  }
  
  public StatefulSetPersistentVolumeClaimRetentionPolicyFluent(StatefulSetPersistentVolumeClaimRetentionPolicy instance) {
    this.copyInstance(instance);
  }
  private String whenDeleted;
  private String whenScaled;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(StatefulSetPersistentVolumeClaimRetentionPolicy instance) {
    instance = (instance != null ? instance : new StatefulSetPersistentVolumeClaimRetentionPolicy());
  
    if (instance != null) {
        this.withWhenDeleted(instance.getWhenDeleted());
        this.withWhenScaled(instance.getWhenScaled());
        this.withWhenDeleted(instance.getWhenDeleted());
        this.withWhenScaled(instance.getWhenScaled());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getWhenDeleted() {
    return this.whenDeleted;
  }
  
  public A withWhenDeleted(String whenDeleted) {
    this.whenDeleted=whenDeleted; return (A) this;
  }
  
  public boolean hasWhenDeleted() {
    return this.whenDeleted != null;
  }
  
  public String getWhenScaled() {
    return this.whenScaled;
  }
  
  public A withWhenScaled(String whenScaled) {
    this.whenScaled=whenScaled; return (A) this;
  }
  
  public boolean hasWhenScaled() {
    return this.whenScaled != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StatefulSetPersistentVolumeClaimRetentionPolicyFluent that = (StatefulSetPersistentVolumeClaimRetentionPolicyFluent) o;
    if (!java.util.Objects.equals(whenDeleted, that.whenDeleted)) return false;
  
    if (!java.util.Objects.equals(whenScaled, that.whenScaled)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(whenDeleted,  whenScaled,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (whenDeleted != null) { sb.append("whenDeleted:"); sb.append(whenDeleted + ","); }
    if (whenScaled != null) { sb.append("whenScaled:"); sb.append(whenScaled + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> kubernetes-model-apps-6.9.1-sources.jar: io/fabric8/kubernetes/api/model/apps/StatefulSetPersistentVolumeClaimRetentionPolicyFluent.java <==
package io.fabric8.kubernetes.api.model.apps;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class StatefulSetPersistentVolumeClaimRetentionPolicyFluent<A extends StatefulSetPersistentVolumeClaimRetentionPolicyFluent<A>> extends BaseFluent<A>{
  public StatefulSetPersistentVolumeClaimRetentionPolicyFluent() {
  }
  
  public StatefulSetPersistentVolumeClaimRetentionPolicyFluent(StatefulSetPersistentVolumeClaimRetentionPolicy instance) {
    this.copyInstance(instance);
  }
  private String whenDeleted;
  private String whenScaled;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(StatefulSetPersistentVolumeClaimRetentionPolicy instance) {
    instance = (instance != null ? instance : new StatefulSetPersistentVolumeClaimRetentionPolicy());
    if (instance != null) {
          this.withWhenDeleted(instance.getWhenDeleted());
          this.withWhenScaled(instance.getWhenScaled());
          this.withWhenDeleted(instance.getWhenDeleted());
          this.withWhenScaled(instance.getWhenScaled());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getWhenDeleted() {
    return this.whenDeleted;
  }
  
  public A withWhenDeleted(String whenDeleted) {
    this.whenDeleted = whenDeleted;
    return (A) this;
  }
  
  public boolean hasWhenDeleted() {
    return this.whenDeleted != null;
  }
  
  public String getWhenScaled() {
    return this.whenScaled;
  }
  
  public A withWhenScaled(String whenScaled) {
    this.whenScaled = whenScaled;
    return (A) this;
  }
  
  public boolean hasWhenScaled() {
    return this.whenScaled != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StatefulSetPersistentVolumeClaimRetentionPolicyFluent that = (StatefulSetPersistentVolumeClaimRetentionPolicyFluent) o;
    if (!java.util.Objects.equals(whenDeleted, that.whenDeleted)) return false;
    if (!java.util.Objects.equals(whenScaled, that.whenScaled)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(whenDeleted,  whenScaled,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (whenDeleted != null) { sb.append("whenDeleted:"); sb.append(whenDeleted + ","); }
    if (whenScaled != null) { sb.append("whenScaled:"); sb.append(whenScaled + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
